* Paddy Carter and Nicolas Van de Sijpe, 11-July-2018
* Monte Carlo analysis


clear all
set more off
version 15.1

* Read elusive.do first, to get an idea of what this file is doing. 

*************************************************************************
* GTOOLS	
*************************************************************************
/*
* We use gtools (version 0.13.1 02May2018) to speed up the MCs run by elusive: https://github.com/mcaceresb/stata-gtools
* To install:
local github "https://raw.githubusercontent.com"
net install gtools, from(`github'/mcaceresb/stata-gtools/master/build/)
* Note for Windows users: It may be necessary to run 
gtools, dependencies 
* at the start of your Stata session.
*/


* Favour mata speed over space:
mata: mata set matafavor speed, perm
* run program
run elusive.do


*************************************************************************
* OLS AND FIXED EFFECTS
*************************************************************************
* first 6: zero additionality.
* 7-12: full additionality.
foreach num of numlist 1/12 {
	local reps = 1000

	* initial value of parameters used here:
	local noise = 0
	local dfilo = 2
	local dfihi = 8
	local psmin = 2
	local mechanism random

	/* 1 = starting point: zero additionality, random selection, no noise: */
	if `num' == 1 {

	}
	/* 2 = zero additionality, random selection, some noise: */
	else if `num' == 2 {
		local noise = 0.5
	}
	/* 3 = zero additionality, random selection, high noise: */
	else if `num' == 3 {
		local noise = 1
	}
	/* 4 = zero additionality, pclow selection mechanism, no noise: */
	else if `num' == 4 {
		local mechanism pclow
	}
	/* 5 = zero additionality, pclow selection mechanism, some noise: */
	else if `num' == 5 {
		local mechanism pclow
		local noise = 0.5
	}
	/* 6 = zero additionality, pclow selection mechanism, high noise: */
	else if `num' == 6 {
		local mechanism pclow
		local noise = 1
	}
	/* 7 = full additionality, pclow selection mechanism, no noise: */
	else if `num' == 7 {
		local dfilo=0
		local dfihi=2
		local psmin=2
		local mechanism pclow
	}
	/* 8 = full additionality, pclow selection mechanism, some noise: */
	else if `num' == 8 {
		local dfilo=0
		local dfihi=2
		local psmin=2
		local mechanism pclow
		local noise = 0.5
	}
	/* 9 = full additionality, pclow selection mechanism, high noise: */
	else if `num' == 9 {
		local dfilo=0
		local dfihi=2
		local psmin=2
		local mechanism pclow
		local noise = 1
	}
	/* 10 = full additionality, random selection mechanism, no noise: */
	else if `num' == 10 {
		local dfilo=0
		local dfihi=2
		local psmin=2
	}
	/* 11 = full additionality, random selection mechanism, some noise: */
	else if `num' == 11 {
		local dfilo=0
		local dfihi=2
		local psmin=2
		local noise = 0.5
	}
	/* 12 = full additionality, random selection mechanism, high noise: */
	else if `num' == 12 {
		local dfilo=0
		local dfihi=2
		local psmin=2
		local noise = 1
	}

	simulate olsbeta=r(olsbeta) olsr2=r(olsr2) olspzeroadd=r(olspzeroadd) olspfulladd=r(olspfulladd) /// 
	olspcbeta=r(olspcbeta) olspcr2=r(olspcr2) olspcpzeroadd=r(olspcpzeroadd) olspcpfulladd=r(olspcpfulladd) ///
	olspcnodfir2=r(olspcnodfir2) olspcnodfinotdummiesr2=r(olspcnodfinotdummiesr2) ///
	febeta=r(febeta) fewr2=r(fewr2) fepzeroadd=r(fepzeroadd) fepfulladd=r(fepfulladd) /// 
	fepcbeta=r(fepcbeta) fepcwr2=r(fepcwr2) fepcpzeroadd=r(fepcpzeroadd) fepcpfulladd=r(fepcpfulladd) ///
	fepcnodfiwr2=r(fepcnodfiwr2) fepcnodfinotdummieswr2=r(fepcnodfinotdummieswr2), /// 
	saving(./Generated data/ols`num'.dta, replace) reps(`reps') seed(150973): elusive, noise(`noise') mechanism(`mechanism') dfilo(`dfilo') dfihi(`dfihi') psmin(`psmin') estimator(OLSFE) 
	
}


*************************************************************************
* GMM
*************************************************************************
* no additionality, first selection mechanism (random)
foreach num of numlist 1/8 {
	local reps = 1000

	* start with no noise no drift, add noise, add drift 
	* note drift is % of DB, so here 1/40th and 1/20th
	*  initial values of parameters used here:
	local noise = 0
	local drift = 0

	/* 1 = starting point, no noise or drift: */
	if `num' == 1 {
	
	}
	/* 2 = low drift, no noise: */
	else if `num' == 2 { // 
		local drift = 0.025
	}
	/* 3 = low noise, no drift: */
	else if `num' == 3 {
		local noise = 0.5
	}
	/* 4 = low drift and low noise: */
	else if `num' == 4 {
		local noise = 0.5
		local drift = 0.025
	}
	/* 5 = low drift and high noise : */
	else if `num' == 5 {
		local noise = 1
		local drift = 0.025
	}
	/* 6 = high drift and low noise */
	else if `num' == 6 {
		local noise = 0.5
		local drift = 0.05
	}
	/* 7 = high drift and high noise */
	else if `num' == 7 {
		local noise = 1
		local drift = 0.05
	}
	/* 8 = high noise, no drift */
	else if `num' == 8 {
		local noise = 1
	}


	simulate sysgmmbeta=r(sysgmmbeta) sysgmmlagdep=r(sysgmmlagdep) sysgmmm1p=r(sysgmmm1p) sysgmmm2p=r(sysgmmm2p) ///
	syshanspval=r(syshanspval) syssargpval=r(syssargpval) diffHp_lev=r(diffHp_lev) diffHp_lagdepdiff=r(diffHp_lagdepdiff) ///
	diffHp_lagdeplevel=r(diffHp_lagdeplevel) diffHp_DFIinv=r(diffHp_DFIinv) diffHp_pc=r(diffHp_pc) /// 
	diffHp_excllev=r(diffHp_excllev) diffHp_excllagdepdiff=r(diffHp_excllagdepdiff) diffHp_excllagdeplevel=r(diffHp_excllagdeplevel) /// 
	diffHp_exclDFIinv=r(diffHp_exclDFIinv) diffHp_exclpc=r(diffHp_exclpc) sysgmmpcpzeroadd=r(sysgmmpcpzeroadd) /// 
	sysgmmpcpfulladd=r(sysgmmpcpfulladd) sysgmmbetaLR=r(sysgmmbetaLR) sysgmmseLR=r(sysgmmseLR) /// 
	sysgmmpcpzeroaddLR=r(sysgmmpcpzeroaddLR) sysgmmpcpfulladdLR=r(sysgmmpcpfulladdLR), ///
	saving(./Generated data/GMM`num'.dta, replace) reps(`reps') seed(150973): elusive, noise(`noise') drift(`drift') estimator(GMM) mechanism(random)
}


*************************************************************************
* SUPPLY-PUSH IV
*************************************************************************
foreach num of numlist 1/9 {
	local reps = 1000

	* defaults
	local phi = 1
	local sig = 0.2
	local tvweight = 0
	local noise = 0.5
	local nD = 3
	local mu1 = 0
	local mu2 = 2
	local mu3 = 4


	/* 1 = starting point: */
	if `num' == 1 {

	}
	/* 2 = single DFI: */
	else if `num' == 2 {
		local nD = 1
	}
	/* 3 = set phi = 0: */
	else if `num' == 3 {
		local phi = 0
	}
	/* 4 = set phi = 2: */
	else if `num' == 4 {
		local phi = 2
	}
	/* 5 = set tvweight = 1 */
	else if `num' == 5 {
		local tvweight = 1
	}
	/* 6 = set phi = 2 and high noise: */
	else if `num' == 6 {
		local phi = 2
		local noise = 1
	}
	/* 7 = sig=0.1, phi = 2: */
	else if `num' == 7 {
		local sig = 0.1
		local phi = 2
	}
	/* 8 = sig=0.1, phi = 2, noise = 1: */
	else if `num' == 8 {
		local sig = 0.1
		local phi = 2
		local noise = 1
	}
	/* 9 = country types all the same: */
	else if `num' == 9 {
		local mu1 = 2
		local mu2 = 2
		local mu3 = 2
	}


	simulate ivbeta=r(ivbeta) ivse=r(ivse) underid=r(underid) underidp=r(underidp) weakid=r(weakid) ///
	ivpzeroadd=r(ivpzeroadd) ivpfulladd=r(ivpfulladd) ivfsbeta=r(ivfsbeta) ivfsse=r(ivfsse) ///
	ivpcbeta=r(ivpcbeta) ivpcse=r(ivpcse) underidpc=r(underidpc) underidppc=r(underidppc) weakidpc=r(weakidpc) ///
	ivpcpzeroadd=r(ivpcpzeroadd) ivpcpfulladd=r(ivpcpfulladd) ivpcfsbeta=r(ivpcfsbeta) ivpcfsse=r(ivpcfsse), /// 
	saving(./Generated data/IV`num'.dta, replace) reps(`reps') seed(150973): /// 
	elusive, phi(`phi') tvweight(`tvweight') nD(`nD') mu1(`mu1') mu2(`mu2') mu3(`mu3') sig(`sig') noise(`noise') estimator(IV) mechanism(random)
}
