* Paddy Carter, Raphael Calel and Nicolas Van de Sijpe, 15-July-2018
* Firm-level simulations


clear all
set more off
version 15.1



*************************************************************************
* GTOOLS	
*************************************************************************
/*
* We use gtools (version 0.13.1 02May2018) to speed up the MCs run by elusive: https://github.com/mcaceresb/stata-gtools
* To install:
local github "https://raw.githubusercontent.com"
net install gtools, from(`github'/mcaceresb/stata-gtools/master/build/)
* Note for Windows users: It may be necessary to run 
gtools, dependencies 
* at the start of your Stata session.
*/


run elusivefirms.do


*******************************************************************************************
* GRAPHS
*******************************************************************************************
/* 1. FIGURE 2, bottom right: no additionality, lower budget, low er error variance to reduce overlap due to that. */
elusivefirms, musd1(2) musd2(2) musd3(2) ersd(.1) dfilo(1) dfihi(3) psmin(1) dfbudg(.1) nI(500) mechanism(random)
keep i pc dfi_inv ps_inv 
/*overlaid histogram */
twoway (histogram pc if dfi_inv==1, width(.1) start(-2) color(red%30) disc freq) (histogram pc if ps_inv==1, width(.1) start(-2) color(blue%30) disc freq), /// 
legend(order(1 "DFIs" 2 "Private")) title("No additionality, DFI funds < opportunities") subtitle("Distributions of project characteristics, DFI and private")
graph export pchisto_noadd_lobudg.pdf, replace


/* 2. FIGURE 2, bottom left: no additionality, large DFI budget, low er error variance to reduce overlap due to that. */ 
elusivefirms, musd1(2) musd2(2) musd3(2) ersd(.1) dfilo(1) dfihi(3) psmin(1) dfbudg(.5) nI(500) mechanism(random)
keep i pc dfi_inv ps_inv
/*overlaid histogram */
twoway (histogram pc if dfi_inv==1, width(.1) start(-2) color(red%30) disc freq ) ( histogram pc if ps_inv==1, width(.1) start(-2) color(blue%30) disc freq  ), /// 
legend(order(1 "DFIs" 2 "Private")) title("No additionality, DFI funds > opportunities") subtitle("Distributions of project characteristics, DFI and private")
graph export pchisto_noadd_hibudg.pdf, replace


/* 3. FIGURE 2, top right: full additionality, lower DFI budget, low er error  */
elusivefirms, musd1(2) musd2(2) musd3(2) ersd(.1)  dfilo(1) dfihi(2.5) psmin(2.5) dfbudg(.2) nI(500) mechanism(random)
keep i pc dfi_inv ps_inv
/*overlaid histogram */
twoway (histogram pc if dfi_inv==1, width(.1) start(-2) color(red%30) disc freq) (histogram pc if ps_inv==1, width(.1) start(-2) color(blue%30) disc freq), ///
 legend(order(1 "DFIs" 2 "Private")) title("Full additionality, small errors") subtitle("Distributions of project characteristics, DFI and private")
graph export pchisto_fulladd_loerror.pdf, replace


/* 4. FIGURE 2, top left: full additionality, lower DFI budget, high er error. */
elusivefirms, musd1(2) musd2(2) musd3(2) ersd(1) dfilo(1) dfihi(2.5) psmin(2.5) dfbudg(.2) nI(500)  mechanism(random)
keep i pc dfi_inv ps_inv
drop if pc<-2
/*overlaid histogram */
twoway (histogram pc if dfi_inv==1, width(.1) start(-2) color(red%30) disc freq) (histogram pc if ps_inv==1, width(.1) start(-2) color(blue%30) disc freq  ), ///
 legend(order(1 "DFIs" 2 "Private")) title("Full additionality, large errors") subtitle("Distributions of project characteristics, DFI and private")
graph export pchisto_fulladd_hierror.pdf, replace


****** Simulated data for section "What could we infer from great data?" (Added by Raphael Calel)
* 5. FIGURE 1: No additionality, lower budget, medium error variance.
elusivefirms, musd1(2) musd2(2) musd3(2) ersd(.3) dfilo(1) dfihi(3) psmin(1) dfbudg(.2) nI(500)  mechanism(random)
keep i pc dfi_inv ps_inv country
/* overlaid histogram */
twoway (histogram pc if dfi_inv==1, width(.1) start(-2) color(red%30) disc freq ) ( histogram pc if ps_inv==1, width(.1) start(-2) color(blue%30) disc freq  ), /// 
legend(order(1 "DFIs" 2 "Private")) title("Predicted probabilities of private investment") subtitle("Distributions of project characteristics, DFI and private")
* Keep only funded projects for now.
keep if dfi_inv==1 | ps_inv==1
* Simple Probit
probit ps_inv pc
predict xb_probit, pr
label variable xb_probit "Probability of Private Investment"
twoway (histogram pc if dfi_inv==1, width(.1) start(-2) color(red%30) disc freq yaxis(1)  legend(off)) ///
( histogram pc if ps_inv==1, width(.1) start(-2) color(blue%30) disc freq  legend(off) ) || /// 
(scatter xb_probit pc,  msymbol(+) msize(tiny) mcolor(black) yaxis(2) yscale(range(0 1) axis(2)) )
graph export firms_probit.pdf, replace


