* Paddy Carter and Nicolas Van de Sijpe, 12-July-2018
* Create tables with results in Excel


clear all
set more off


*************************************************************************
* OLS and FE
*************************************************************************
foreach num of numlist 1/12 {
	clear
	capture log close
	log using "./Generated data/OLS`num'", replace text
	use "./Generated data/OLS`num'.dta"


	/* Selected statistics to export to Excel later: */
	/* OLS */
	qui su olsbeta, detail
	scalar olsmean = r(mean)
	scalar olssd = r(sd)
	//
	count if olspzeroadd < 0.05
	scalar olspzeroaddpercreject = (r(N)/_N)*100
	//
	qui su olsr2
	scalar olsr2mean = r(mean)
	//
	qui su olspcbeta, detail
	scalar olspcmean = r(mean)
	scalar olspcsd = r(sd)
	//
	count if olspcpzeroadd < 0.05
	scalar olspcpzeroaddpercreject = (r(N)/_N)*100	
	//
	qui su olspcr2
	scalar olspcr2mean = r(mean)
	qui su olspcnodfir2
	scalar olspcnodfir2mean = r(mean)
	qui su olspcnodfinotdummiesr2
	scalar olspcnodfinotdummiesr2mean = r(mean)

	/* FE */
	qui su febeta, detail
	scalar femean = r(mean)
	scalar fesd = r(sd)
	//
	count if fepzeroadd < 0.05
	scalar fepzeroaddpercreject=(r(N)/_N)*100
	//
	qui su fewr2
	scalar fewr2mean = r(mean)
	//
	qui su fepcbeta, detail
	scalar fepcmean = r(mean)
	scalar fepcsd = r(sd)
	//
	count if fepcpzeroadd < 0.05
	scalar fepcpzeroaddpercreject=(r(N)/_N)*100
	//
	qui su fepcwr2
	scalar fepcwr2mean = r(mean)
	qui su fepcnodfiwr2
	scalar fepcnodfiwr2mean = r(mean)
	qui su fepcnodfinotdummieswr2
	scalar fepcnodfinotdummieswr2mean = r(mean)

	
	// Put statistics in matrix:
	matrix OLS_`num' = (olsmean \ olssd \ olspzeroaddpercreject \ olsr2mean \ olspcmean \ olspcsd \ olspcpzeroaddpercreject \ olspcr2mean \ olspcnodfir2mean \ olspcnodfinotdummiesr2mean /// 
	\ femean \ fesd \ fepzeroaddpercreject \ fewr2mean \ fepcmean \ fepcsd \ fepcpzeroaddpercreject \ fepcwr2mean \ fepcnodfiwr2mean \ fepcnodfinotdummieswr2mean)
	matrix list OLS_`num'

	log close
}


/* Construct matrices that combine results. */
/* First table: */
foreach num of numlist 1/12 {
	if `num'==1 { 
		matrix tableOLS = OLS_`num'
	}
    else { 
		matrix tableOLS=(tableOLS, OLS_`num')
	}        
}


/* Export to Excel and clean up tables. */
/* First table: */
putexcel set "./Tables/OLStable", replace
putexcel B2 = matrix(tableOLS) // starting point of table
//
putexcel A2 = "OLS Mean"
putexcel A3 = "OLS St. dev."
putexcel A4 = "OLS % reject zero additionality"
putexcel A5 = "OLS R2"
putexcel A6 = "OLS PC Mean"
putexcel A7 = "OLS PC St. dev."
putexcel A8 = "OLS PC % reject zero additionality"
putexcel A9 = "OLS with PC R2"
putexcel A10 = "OLS PC no DFI R2"
putexcel A11 = "OLS PC no DFI and no t dummies R2"
//
putexcel A12 = "FE Mean"
putexcel A13 = "FE St. dev."
putexcel A14 = "FE % reject zero additionality"
putexcel A15 = "FE within R2"
putexcel A16 = "FE PC Mean"
putexcel A17 = "FE PC St. dev."
putexcel A18 = "FC PC % reject zero additionality"
putexcel A19 = "FE with PC within R2"
putexcel A20 = "FE PC no DFI within R2"
putexcel A21 = "FE PC no DFI no t dummies within R2"
//
putexcel B1= "Zero add., random, no noise"
putexcel C1= "Zero add., random, some noise"
putexcel D1= "Zero add., random, high noise"
putexcel E1= "Zero add., pclow, no noise"
putexcel F1= "Zero add., pclow, some noise"
putexcel G1= "Zero add., pclow, high noise"
putexcel H1= "Full add., pclow, no noise"
putexcel I1= "Full add., pclow, some noise"
putexcel J1= "Full add., pclow, high noise"
putexcel K1= "Full add., random, no noise"
putexcel L1= "Full add., random, some noise"
putexcel M1= "Full add., random, high noise"


*************************************************************************
* GMM
*************************************************************************
foreach num of numlist 1/8 {
	clear
	capture log close
	log using "./Generated data/GMM`num'", replace text
	use "./Generated data/gmm`num'.dta"
	

	/* Selected statistics to export to Excel later: */
	qui su sysgmmbeta, detail
	scalar gmmmean = r(mean)
	scalar gmmmedian = r(p50)
	scalar gmmsd = r(sd)
	//
	count if sysgmmpcpzeroadd < 0.05
	scalar gmmpzeroaddpercreject = (r(N)/_N)*100
	// Count fraction of diagnostic tests that "pass" (i.e. suggest no problem with GMM)
	count if sysgmmm1p < 0.1
	scalar gmmar1 = (r(N)/_N)*100
	count if sysgmmm2p > 0.1
	scalar gmmar2 = (r(N)/_N)*100
	count if syshanspval > 0.1
	scalar gmmhan = (r(N)/_N)*100
	count if syssargpval > 0.1
	scalar gmmsarg = (r(N)/_N)*100
	
	foreach moment in lev lagdepdiff lagdeplevel DFIinv pc {
		count if diffHp_`moment' > 0.1
		scalar gmm`moment'pass = (r(N)/_N)*100
	}
		
	// Put statistics in matrix:
	matrix GMM_`num' = (gmmmean \ gmmmedian \ gmmsd \ gmmpzeroaddpercreject \ gmmar1 \ gmmar2 \ gmmhan \ gmmsarg ///
	\ gmmlevpass \ gmmlagdepdiffpass \ gmmlagdeplevelpass \ gmmDFIinvpass \ gmmpcpass)
	matrix list GMM_`num'

	log close
}


/* Construct matrices that combine results. */
/* First table: */
foreach num of numlist 1/8 {
	if `num'==1 { 
		matrix tableGMM = GMM_`num'
	}
    else { 
		matrix tableGMM=(tableGMM, GMM_`num')
	}        
 }
 

/* Export to Excel and clean up tables. */
/* First table: */
putexcel set "./Tables/GMMtable", replace
putexcel B2 = matrix(tableGMM) // starting point of table
//
putexcel A2 = "GMM Mean"
putexcel A3 = "GMM Median"
putexcel A4 = "GMM St. dev."
putexcel A5 = "GMM % reject zero additionality"
//
putexcel A6 = "GMM m1"
putexcel A7 = "GMM m2"
putexcel A8 = "GMM hansen"
putexcel A9 = "GMM sargan"
//
putexcel A10 = "GMM dHansen level %pass"
putexcel A11 = "GMM dHansen lagdep diff %pass"
putexcel A12 = "GMM dHansen lagdep level %pass"
putexcel A13 = "GMM dHansen DFI inv %pass"
putexcel A14 = "GMM dHansen pc %pass"
//
putexcel B1= "No noise no drift"
putexcel C1= "No noise low drift"
putexcel D1= "Low noise no drift"
putexcel E1= "Low noise low drift"
putexcel F1= "High noise low drift"
putexcel G1= "Low noise high drift"
putexcel H1= "High noise high drift"
putexcel I1= "High noise no drift"


*************************************************************************
* SUPPLY-PUSH IV
*************************************************************************
foreach num of numlist 1/9 {
	clear
	capture log close
	log using "./Generated data/IV`num'", replace text
	use "./Generated data/IV`num'.dta"
	
	/* Overview of results: */
	su ivbeta ivpcbeta, detail
	count if ivpzeroadd < 0.05
	count if ivpcpzeroadd < 0.05
	su ivse ivpcse, detail
	//
	su underid underidp underidpc underidppc weakid weakidpc, detail
	su *fsbeta, detail

	/* Now pick up selected IV statistics to export to Excel later: */
	qui su ivbeta, detail
	scalar IVmean=r(mean)
	scalar IVmedian=r(p50)
	scalar IVsd=r(sd)
	qui su ivpcbeta, detail
	scalar IVpcmean=r(mean)
	scalar IVpcmedian=r(p50)
	scalar IVpcsd=r(sd)
	//
	count if ivpzeroadd < 0.05
	scalar IVzeroaddpercreject=(r(N)/_N)*100
	count if ivpcpzeroadd < 0.05
	scalar IVpczeroaddpercreject=(r(N)/_N)*100
	//
	qui su weakid, detail
	scalar IVmedFSF=r(p50)
	count if weakid > 10 & weakid != .
	scalar IVFSFperchigh=(r(N)/_N)*100
	qui su weakidpc, detail
	scalar IVpcmedFSF=r(p50)
	count if weakidpc > 10 & weakidpc != .
	scalar IVpcFSFperchigh=(r(N)/_N)*100

	// Put statistics in matrix:
	matrix IV_`num' = (IVmean \ IVmedian \ IVsd \ IVzeroaddpercreject \ IVmedFSF \ IVFSFperchigh /// 
	\ IVpcmean \ IVpcmedian \ IVpcsd \ IVpczeroaddpercreject \ IVpcmedFSF \ IVpcFSFperchigh)
	matrix list IV_`num'

	log close
}


/* Construct matrices that combine results. */
foreach num of numlist 1/9 {
	if `num'==1 { 
		matrix tableIV = IV_`num'
	}
    else { 
		matrix tableIV=(tableIV, IV_`num')
	}        
}

 
/* Export to Excel and clean up tables. */
putexcel set "./Tables/IVtable", replace
putexcel C2 = matrix(tableIV) // starting point of table
//
putexcel A2 = "Without pc"
putexcel A8 = "With pc"
//
putexcel B2 = "Mean"
putexcel B3 = "Median"
putexcel B4 = "St. dev."
putexcel B5 = "% reject zero additionality"
putexcel B6 = "Median F"
putexcel B7 = "% F > 10"
//
putexcel B8 = "Mean"
putexcel B9 = "Median"
putexcel B10 = "St. dev."
putexcel B11= "% reject zero additionality"
putexcel B12= "Median F"
putexcel B13= "% F > 10"
//
putexcel C1= "Default"
putexcel D1= "Single DFI"
putexcel E1= "phi = 0"
putexcel F1= "phi = 2"
putexcel G1= "tvweight = 1"
putexcel H1= "phi = 2, noise = 1"
putexcel I1= "sig = 0.1, phi = 2"
putexcel J1= "sig = 0.1, phi = 2, noise = 1"
putexcel K1= "equal mus"


/* Extra analysis */
/* For default setup, check median and mean estimate in subset of replications with F > 40. */
clear
use "./Generated data/IV1.dta"
su ivbeta if weakid > 40, detail
